"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const glob_1 = __importDefault(require("glob"));
const env_1 = require("../../util/env");
/**
 * Preflight check for ESLint configurations
 *
 * If there are .eslintrc.* files in the root project, but the override argument was not passed to TNS, it will display a warning
 * If the argument is passed but no .eslintrc.* files are detected, it will display an error, and stop the program
 */
function checkCustomEslintRequirements() {
    try {
        const matches = glob_1.default.sync('.eslintrc.*');
        if (matches.length) {
            if (!env_1.RuntimeOptions.overrideEslintConfig) {
                console.log(chalk_1.default.yellow(`• Ignoring .eslintrc.* files for compilation, since the argument '${env_1.TNS_ARGUMENTS.OVERRIDE_ESLINT_CONFIG}' was not passed`));
            }
            else {
                console.log(chalk_1.default.cyan('• Using custom .eslintrc.* files'));
            }
        }
        if (!matches.length && env_1.RuntimeOptions.overrideEslintConfig) {
            console.log(chalk_1.default.redBright(`You've passed the argument '${env_1.TNS_ARGUMENTS.OVERRIDE_ESLINT_CONFIG}' but there was no ESLint configuration file(s) (.eslintrc.*) found.`));
            console.log(chalk_1.default.redBright(`Either add a valid configuration(s), or remove this argument from the 'typescript-node-scripts' command in 'package.json'.`));
            console.log();
            process.exit(1);
        }
    }
    catch (err) {
        console.error(err);
        return process.exit(1);
    }
}
exports.checkCustomEslintRequirements = checkCustomEslintRequirements;
//# sourceMappingURL=checkCustomEslintRequirements.js.map